@@ -50,11 +50,11 @@ class GridHandler():
     
     @staticmethod
     def submit(config_input:str, n_jobs=1, site=None, time=-1, mode='grid'):
-        config = preprocess_config(config_input)
+        config = GridHandler.preprocess_config(config_input)
         if mode == 'grid':
-            self.submit_grid(config, n_jobs=n_jobs, site=site, time=time)
+            GridHandler.submit_grid(config, n_jobs=n_jobs, site=site, time=time)
         elif mode == 'idds':
-            self.submit_idds(config, n_jobs=n_jobs, site=site)
+            GridHandler.submit_idds(config, n_jobs=n_jobs, site=site)
         else:
             raise ValueError('Unknown job submission mode: {}'.format(mode))
             
@@ -84,8 +84,8 @@ class GridHandler():
                 json.dump(idds_config, idds_config_file)
             with open(search_space_path, 'w') as search_space_file:
                 json.dump(search_space, search_space_file)  
-            command = self.format_idds_command(idds_config_path, 
-                                               search_space_path,
+            command = GridHandler.format_idds_command(config, 
+                                               tmpdirname,
                                                site=site)
             with helper.cd(project_path):
                 # submit jobs
@@ -95,16 +95,20 @@ class GridHandler():
     def submit_grid(config, n_jobs=1, site=None, time=-1):
         project_path = helper.get_project_path(config['project_name'])
         print('INFO: Submitting {} grid job(s)'.format(n_jobs))
-        command = format_grid_command(config, site=site, time=time)
+        command = GridHandler.format_grid_command(config, site=site, time=time)
         with helper.cd(project_path):
             # submit jobs
             for _ in range(n_jobs):
                 os.system(command)
                 
     @staticmethod
-    def format_idds_command(config_path, search_space_path, site=None):
-        options = {'loadJson': config_path,
+    def format_idds_command(config, tmpdirname, site=None):
+        idds_config_path = os.path.join(tmpdirname, 'idds_config.json')
+        search_space_path = os.path.join(tmpdirname, 'search_space.json')
+        options = {'loadJson': idds_config_path,
                    'searchSpaceFile': search_space_path}
+        proj_name = config['project_name']
+        grid_config = config['grid_config']
         # override site settings if given
         if not site:
             site = grid_config['site']
@@ -114,6 +118,17 @@ class GridHandler():
             # specify architecture for gpu/cpu site
             if 'GPU' in site:
                 options['architecture'] = 'nvidia-gpu'
+        # options excluded from idds configuration file due to
+        # possible bash variable expansion
+        in_ds = config['grid_config']['inDS']
+        out_ds = config['grid_config']['outDS']
+        
+        if in_ds:
+            options['trainingDS'] = in_ds
+            
+        if '{HPO_PROJECT_NAME}' in out_ds:
+            out_ds = out_ds.format(HPO_PROJECT_NAME=proj_name)
+        options['outDS'] = out_ds
                 
         command = 'phpo {}'.format(stylus.join_options(options))    
         return command
@@ -156,8 +171,6 @@ class GridHandler():
             # specify architecture for gpu/cpu site
             if 'GPU' in site:
                 options['cmtConfig'] = 'nvidia-gpu'
-            else:
-                options['nCore'] = '8'
         
         command = 'prun {}'.format(stylus.join_options(options))
                 
