@@ -11,7 +11,6 @@ from hpogrid.components import environment_settings
 from hpogrid.components.validation import validate_project_config
 
 def transpose_config(config):
-    config = validate_project_config(config)
     project_name = config['project_name']
     evaluation_container = config['grid_config']['container']
     search_space = config['search_space']
@@ -19,10 +18,7 @@ def transpose_config(config):
     method = config['hpo_config']['algorithm_param'].get('method', None)
     max_point = config['hpo_config']['num_trials']
     max_concurrent = config['hpo_config']['max_concurrent']
-    in_ds = config['grid_config']['inDS']
-    out_ds = config['grid_config']['outDS']
-    if '{HPO_PROJECT_NAME}' in out_ds:
-        out_ds = out_ds.format(HPO_PROJECT_NAME=project_name)
+
 
     # format generator command
     generator_options = {}
@@ -47,9 +43,6 @@ def transpose_config(config):
     idds_config['evaluationMeta'] = kGridSiteMetadataFileName
     idds_config['nParallelEvaluation'] = max_concurrent
     idds_config['maxPoints'] = max_point
-    if in_ds:
-        idds_config['trainingDS'] = in_ds
-    idds_config['outDS'] = out_ds
     return idds_config, search_space
 
 
